{% load i18n %}
{% if revisions %}
    <div class="revisions">
        <h4>{% trans "Revisions" %}</h4>
        
        <ul class="revisions-list">
        {% for revision in revisions %}
            <li><a href="./get-content/{{ revision.id }}/" {% if forloop.first %} class="selected"{% endif %}>{{ revision.creation_date|date:_("DATETIME_FORMAT") }}</a></li>
        {% endfor %}
        </ul>
    </div>
{% endif %}
