{% extends "admin/change_form.html" %}
{% load i18n admin_modify adminmedia pages_tags %}
{% block title %}{% trans "Change a page" %}{% endblock %}

{% block extrahead %}{{ block.super }}
<script type="text/javascript" src="{% admin_media_prefix %}js/urlify.js"></script>
<script type="text/javascript" src="../jsi18n/"></script>
{% endblock %}

{% block content %}
<!-- Content -->
<div id="content-main">

{% block object-tools %}
{% if change %}{% if not is_popup %}
  <ul class="object-tools">
  {% if has_absolute_url %}<li><a href="{{ page.get_absolute_url }}" class="viewsitelink">{% trans "View on site" %}</a></li>{% endif%}
  </ul>
{% endif %}{% endif %}
{% endblock %}

<form action="?language={{ language }}{%if request.GET.target %}&amp;target={{ request.GET.target }}{% endif %}&amp;{%if request.GET.target %}position={{ request.GET.position }}{% endif %}" method="post" id="page_form">
{% for fieldset in adminform %}
  {% include "admin/pages/page/includes/fieldset.html" %}
{% endfor %}
<br class="clear" />
{% if not add %}
<div><fieldset class="module aligned ">
  <h2>{% trans "Translation helper" %}</h2>
  <div class="form-row">
      <label for="traduction-helper-select" class="required">{% trans "Language:" %}</label>
      <select id="traduction-helper-select">
      <option value="" selected="selected">------</option>
      {% for lang in traduction_language %}
      <option value="{{ lang.0 }}">{{ lang.1 }}</option>
      {% endfor %}
      </select>
      <div id="traduction-helper-content"></div>
  </div>
</fieldset>
</div>
{% endif %}

{% submit_row %}
</div>
</form>

<br class="clear" />
<!-- END Content -->
{% endblock %}
