{% extends "admin/change_list.html" %}
{% load adminmedia admin_list i18n pages_tags %}
{% block title %}{% trans "List of pages" %}{% endblock %}
{% block bodyclass %}change-list{% endblock %}

{% if not is_popup %}{% block breadcrumbs %}
    <div class="breadcrumbs">
    <a href="../../">{% trans "Home" %}</a> &rsaquo; 
    <a href="../">{{ app_label|capfirst|escape }}</a> &rsaquo; {{ opts.verbose_name_plural|capfirst|escape }}
    </div>
{% endblock %}{% endif %}

{% block coltype %}flex{% endblock %}
{% block extrahead %}{{ block.super }}
<link rel="stylesheet" type="text/css" href="{{ PAGES_MEDIA_URL }}css/rte.css" />
<link rel="stylesheet" type="text/css" href="{{ PAGES_MEDIA_URL }}css/pages.css" />
<script type="text/javascript" src="{{ PAGES_MEDIA_URL }}javascript/jquery.js"></script>
<script type="text/javascript" src="{{ PAGES_MEDIA_URL }}javascript/jquery.query.js"></script>
<script type="text/javascript" src="{{ PAGES_MEDIA_URL }}javascript/change_list.js"></script>
{% endblock %}


{% block content %}
<div id="content-main">

{% if has_add_permission %}
<ul class="object-tools"><li><a href="add/" class="addlink">{% blocktrans %}Add {{ name }}{% endblocktrans %}</a></li></ul>
{% endif %}

<div class="module" id="changelist">

{% include "admin/pages/page/change_list_table.html" %}

</div>
</div>
</div>

{% endblock %}